@@ -28,6 +28,10 @@ from gitflow.exceptions import (NotInitialized, BranchExistsError,
 __copyright__ = "2010-2011 Vincent Driessen; 2012 Hartmut Goebel"
 __license__ = "BSD"
 
+
+# A magic string to be used for encoding '-' in git config.
+MAGIC_STRING = 'dKkvQvtBsd9DkQfMJkya'
+
 def datetime_to_timestamp(d):
     return time.mktime(d.timetuple()) + d.microsecond / 1e6
 
@@ -108,6 +112,7 @@ class GitFlow(object):
             'gitflow.prefix.versiontag': '',
             'gitflow.origin': 'origin',
             'gitflow.release.versionmatcher': '[0-9]+([.][0-9]+){2}',
+            'gitflow.pagination': 10,
             }
         for identifier, manager in self.managers.items():
             self.defaults['gitflow.prefix.%s' % identifier] = manager.DEFAULT_PREFIX
@@ -172,6 +177,14 @@ class GitFlow(object):
         info('Switching to branch %s' % branch)
         branch.checkout()
 
+    def _ensure_remote_develop_branch(self):
+        # push the develop branch if it does not exist in origin
+        remote_develop = self.origin_name(self.develop_name())
+        if not remote_develop in self.branch_names(remote=True):
+            develop_name = self.develop_name()
+            sys.stdout.write('Branch {0} not found in origin, pushing it now ... '.format(develop_name))
+            self.origin().push([develop_name])
+            print('OK')
 
     def _enforce_git_repo(self):
         """
@@ -224,6 +237,7 @@ Git config '%s' missing, please fill it in by executing
         self._init_config(master, develop, prefixes, names, force_defaults)
         self._init_initial_commit()
         self._init_develop_branch()
+        self._ensure_remote_develop_branch()
         return self
 
     def is_initialized(self):
@@ -235,7 +249,8 @@ Git config '%s' missing, please fill it in by executing
                 self.is_set('gitflow.prefix.hotfix') and
                 self.is_set('gitflow.prefix.support') and
                 self.is_set('gitflow.prefix.versiontag') and
-                self.is_set('gitflow.release.versionmatcher'))
+                self.is_set('gitflow.release.versionmatcher') and
+                self.is_set('gitflow.pagination'))
 
     def _parse_setting(self, setting):
         groups = setting.split('.', 2)
@@ -252,7 +267,13 @@ Git config '%s' missing, please fill it in by executing
     def get(self, setting, default=_NONE):
         section, option = self._parse_setting(setting)
         try:
-            return self.repo.config_reader().get_value(section, option)
+            value = self.repo.config_reader().get_value(section, option)
+            # git config value cannot contain '-', so it is encoded as
+            # MAGIC_STRING and we have to replace it with '-' when we read a
+            # value.
+            if isinstance(value, basestring):
+                value = value.replace(MAGIC_STRING, '-')
+            return value
         except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
             if default is not _NONE:
                 return default
@@ -263,12 +284,19 @@ Git config '%s' missing, please fill it in by executing
 
     @requires_repo
     def set(self, setting, value):
+        # git config value cannot contain '-', so we have to encode it.
+        if isinstance(value, basestring):
+            value = value.replace('-', MAGIC_STRING)
         section, option = self._parse_setting(setting)
         self.repo.config_writer().set_value(section, option, value)
 
     def is_set(self, setting):
         return self.get(setting, None) is not None
 
+    @requires_repo
+    def delete(self, setting):
+        section, option = self._parse_setting(setting)
+        self.repo.config_writer().remove(section, option)
 
     @requires_repo
     def _safe_get(self, setting_name):
@@ -401,7 +429,17 @@ Git config '%s' missing, please fill it in by executing
             else:
                 raise NoSuchBranchError('The current branch is no %s branch. '
                     'Please specify one explicitly.' % identifier)
-        return manager.shorten(manager.by_name_prefix(prefix).name)
+        branch = None
+        try:
+            branch = manager.by_name_prefix(prefix).name
+        except NoSuchBranchError as ex:
+            try:
+                remote_branch = manager.by_name_prefix(prefix, remote=True).name
+                branch = str(remote_branch)[len(self.origin_name())+1:]
+                self.git.branch(branch, remote_branch)
+            except NoSuchBranchError:
+                raise ex
+        return manager.shorten(branch)
 
     @requires_repo
     def name_or_current(self, identifier, name, must_exist=True):
